# Foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Testing that "link-with-dashes" is not the same as "link with dashes".

link with dashes link-with-dashes property-with-dashes

link with dashes link-with-dashes property-with-dashes

anchor with dashes anchor-with-dashes anchor-property-with-dashes

## Index

### Terms defined by this specification

- link with dashes, in §Unnumbered section
- link-with-dashes, in §Unnumbered section
- property-with-dashes, in §Unnumbered section

#link-with-dashes Referenced in:

- Unnamed section

#link-with-dashes① Referenced in:

- Unnamed section

#propdef-property-with-dashes Referenced in:

- Unnamed section